<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs_CZ">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Seafile Drive Client %2&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Seafile Drive Klient %2&lt;/h4&gt;</translation>
    </message>
    <message>
        <source>&lt;h5&gt; REV %1 &lt;/h5&gt;</source>
        <translation>&lt;h5&gt; REV %1 &lt;/h5&gt;</translation>
    </message>
    <message>
        <source>About</source>
        <translation>&amp;O aplikaci</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>failed to open account database</source>
        <translation>Nepodařilo se otevřít databázi účtů</translation>
    </message>
</context>
<context>
    <name>AutoLogonDialog</name>
    <message>
        <source>auto login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>auto logining, please wait a moment</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please input server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>login failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DaemonManager</name>
    <message>
        <source>%1 failed to initialize</source>
        <translation>%1 se nepodařilo spustit</translation>
    </message>
    <message>
        <source>%1 exited unexpectedly</source>
        <translation>%1 Neočekávané ukončení</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create seadrive mount folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EncryptedReposDialog</name>
    <message>
        <source>Encrypted Libraries</source>
        <translation>Šifrované knihovny</translation>
    </message>
    <message>
        <source>No Encrypted Library.</source>
        <translation>Žádná šifrovaná knihovna</translation>
    </message>
</context>
<context>
    <name>EncryptedReposTableModel</name>
    <message>
        <source>Failed to set encrypted library password</source>
        <translation>Nepodařilo se nastavit heslo šifrované knihovně</translation>
    </message>
    <message>
        <source>Password error</source>
        <translation>Chyba hesla</translation>
    </message>
    <message>
        <source>Failed to clear encrypted library password</source>
        <translation>Nepodařilo se smazat heslo šifrované knihovně</translation>
    </message>
    <message>
        <source>Right click this item to sync or unsync the encrypted library</source>
        <translation>Klikni pravým tlačítkem na tuto položku pro synchronizaci nebo desynchronizaci šifrované knihovny</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Knihovna</translation>
    </message>
    <message>
        <source>Sync status</source>
        <translation>Status synchronizace</translation>
    </message>
    <message>
        <source>Server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EncryptedReposTableView</name>
    <message>
        <source>Unsync</source>
        <translation>Desynchronizovat</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Synchronizovat</translation>
    </message>
    <message>
        <source>After unsyncing, the local encryption key of this library will be cleared and this library cannot be accessed in virtual drive. Are you sure to unsync?</source>
        <translation>Po desynchronizaci bude lokální šifrovací klíč této knihovny vymazán a knihovna nebude přístupná ve virtuální jednotce. Opravdu chceš desynchronizovat ?</translation>
    </message>
    <message>
        <source>Enter library password to sync</source>
        <translation>Zadej heslo ke knihovně pro synchronizaci</translation>
    </message>
</context>
<context>
    <name>ExtCommandsHandler</name>
    <message>
        <source>Are you sure to remove account from &quot;%1&quot;? Downloaded and uploading files will not be removed.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to connect to background process, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to resync account from &quot;%1&quot;? Downloaded and uploading files will not be removed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileProviderManager</name>
    <message>
        <source>%1 will ask permissions to enable Finder plugin.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FilterMenu</name>
    <message>
        <source>FilterMenu</source>
        <translation>Filtr</translation>
    </message>
    <message>
        <source>Text file    </source>
        <translation>Textový soubor</translation>
    </message>
    <message>
        <source>Document    </source>
        <translation>Dokument</translation>
    </message>
    <message>
        <source>Image    </source>
        <translation>Obrázek</translation>
    </message>
    <message>
        <source>Video    </source>
        <translation>Video soubor</translation>
    </message>
    <message>
        <source>Audio    </source>
        <translation>Zvukový soubor</translation>
    </message>
    <message>
        <source>Markdown</source>
        <translation>Označení</translation>
    </message>
</context>
<context>
    <name>InitSyncDialog</name>
    <message>
        <source>Download files list</source>
        <translation>Stáhnout seznam souborů</translation>
    </message>
    <message>
        <source>%1 is fetching the files list, please wait</source>
        <translation>%1 stahuje seznam souborů, prosím čekejte</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Run in Background</source>
        <translation>Na pozadí</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>Dokončit</translation>
    </message>
    <message>
        <source>%1 has downloaded your files list.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LoadMoreButton</name>
    <message>
        <source>load more</source>
        <translation>načíst více</translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Add an account</source>
        <translation>Přidat účet</translation>
    </message>
    <message>
        <source>Single Sign On</source>
        <translation>Single Sign On - SSO</translation>
    </message>
    <message>
        <source>Re-login</source>
        <translation>Znovu přihlášit</translation>
    </message>
    <message>
        <source>Logging in...</source>
        <translation>Přihlašuji se...</translation>
    </message>
    <message>
        <source>Network Error:
 %1</source>
        <translation>Chyba sítě:
%1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Varování:&lt;/b&gt; SSL certifikát serveru není důvěryhodný, přesto pokračovat?</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Vložte adresu serveru</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 není platná adresa serveru</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>Vaše uživatelské jméno</translation>
    </message>
    <message>
        <source>Please enter the computer name</source>
        <translation>Název počítače</translation>
    </message>
    <message>
        <source>Two Factor Authentication</source>
        <translation>Dvoufaktorová autentikace</translation>
    </message>
    <message>
        <source>%1 Server Address</source>
        <translation>Adresa serveru %1</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Vložte heslo</translation>
    </message>
    <message>
        <source>Enter the two factor authentication token</source>
        <translation>Zadejte dvoufaktorový autentifikační token</translation>
    </message>
    <message>
        <source>Incorrect email or password</source>
        <translation>Nesprávný email nebo heslo</translation>
    </message>
    <message>
        <source>Logging in too frequently, please wait a minute</source>
        <translation>Přihlašujete se příliš často, prosím počkejte chvíli</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Vnitřní chyba serveru</translation>
    </message>
    <message>
        <source>Failed to login: %1</source>
        <translation>Chyba při přihlášení: %1</translation>
    </message>
    <message>
        <source>Failed to login</source>
        <translation>Chyba při přihlášení</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <source>or http://192.168.1.24:8000</source>
        <translation>nebo http://192.168.1.24:8000</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Automatic Login</source>
        <translation>Automatické přihlášení</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>stavový text</translation>
    </message>
    <message>
        <source>Computer Name:</source>
        <translation>Název počítače:</translation>
    </message>
    <message>
        <source>Email / Username:</source>
        <translation>Email / Uživ. jméno:</translation>
    </message>
    <message>
        <source>e.g. Jim&apos;s laptop</source>
        <translation>například Honzův počitač</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Failed to get server info. Please check the server address.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get client sso link.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SSO login failed.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get client sso status.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://example.your-server.com&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync Root Folder Name:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync root folder name cannot be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync root folder name cannot contain the following characters: &lt; &gt; : &quot; / \ | ? *</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Files in this account will be synced under the path like &apos;C:\Users\Jim\seadrive_root\&amp;lt;sync root folder name&amp;gt;&apos;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessagePoller</name>
    <message>
        <source>&quot;%1&quot; is synchronized</source>
        <translation>&quot;%1&quot; je synchronizován</translation>
    </message>
    <message>
        <source>Error when syncing &quot;%1&quot;</source>
        <translation>Při synchronizaci &quot;%1&quot; nastala chyba</translation>
    </message>
    <message>
        <source>Error when syncing</source>
        <translation>Chyba při synchronizaci</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is being uploaded</source>
        <translation>&quot;%1&quot; se právě nahrává</translation>
    </message>
    <message>
        <source>Starting to move &quot;%1&quot;</source>
        <translation>Začínám přesun &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Starting to move &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>Začínám přesun &quot;%1&quot; do &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Successfully moved &quot;%1&quot;</source>
        <translation>&quot;%1&quot; úspěšně přesunut</translation>
    </message>
    <message>
        <source>Successfully moved &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>&quot;%1&quot; úspěšně přesunut do &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Failed to move &quot;%1&quot;</source>
        <translation>Přesunutí &quot;%1&quot; se nezdařilo</translation>
    </message>
    <message>
        <source>Failed to move &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>Přesunutí &quot;%1&quot; do &quot;%2&quot; se nezdařilo</translation>
    </message>
    <message>
        <source>Download file</source>
        <translation>Stáhnout soubor</translation>
    </message>
    <message>
        <source>Start to download file &quot;%1&quot; </source>
        <translation>Stáhnout soubor &quot;%1&quot; </translation>
    </message>
    <message>
        <source>file &quot;%1&quot; has been downloaded </source>
        <translation>Soubor &quot;%1&quot; byl stažen </translation>
    </message>
    <message>
        <source>Failed to create file &quot;%1&quot;</source>
        <translation>Chyba při vytvoření souboru &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to delete folder</source>
        <translation>Chyba při mazaní složky souborů</translation>
    </message>
    <message>
        <source>You can&apos;t delete the library &quot;%1&quot; directly</source>
        <translation>Nemůžeš smazat knihovnu &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Libraries are ready</source>
        <translation>Knihovny jsou připraveny</translation>
    </message>
    <message>
        <source>All libraries are loaded and ready to use.</source>
        <translation>Všechny knihovny jsou načtené a připravené k použití.</translation>
    </message>
    <message>
        <source>Deleted &quot;%1&quot; and %2 more files.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You can&apos;t create files in the mount folder directly</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do you want to delete files in library &quot;%1&quot; ?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Confirm to delete library &quot;%1&quot; ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>File %1 is locked by other programs</source>
        <translation>Soubor %1 je uzamčen jiným programem</translation>
    </message>
    <message>
        <source>Some file is locked by other programs</source>
        <translation>Některý soubor je uzamčen jiným programem</translation>
    </message>
    <message>
        <source>Folder %1 is locked by other programs</source>
        <translation>Adresář %1 je uzamčen jiným programem</translation>
    </message>
    <message>
        <source>Some folder is locked by other programs</source>
        <translation>Některý adresář je uzamčen jiným programem</translation>
    </message>
    <message>
        <source>File %1 is locked by another user</source>
        <translation>Soubor %1 je uzamčen jiným uživatelem</translation>
    </message>
    <message>
        <source>Some file is locked by another user</source>
        <translation>Některý adresář je uzamčen jiným uživatelem</translation>
    </message>
    <message>
        <source>Invalid path %1</source>
        <translation>Neplatná cesta %1</translation>
    </message>
    <message>
        <source>Trying to access an invalid path</source>
        <translation>Pokus o přístup ke špatné cestě</translation>
    </message>
    <message>
        <source>Error when indexing file %1</source>
        <translation>Při indexaci souboru %1 nastala chyba</translation>
    </message>
    <message>
        <source>Error when indexing files</source>
        <translation>Při indexaci souborů nastala chyba</translation>
    </message>
    <message>
        <source>You don&apos;t have enough permission for this library</source>
        <translation>Pro tuto knihovnu nemáte dostatečná oprávnění</translation>
    </message>
    <message>
        <source>Network error</source>
        <translation>Chyba připojení</translation>
    </message>
    <message>
        <source>Failed to resolve network proxy</source>
        <translation>Nepovedlo se rozlišit síťovou proxy</translation>
    </message>
    <message>
        <source>Failed to resolve remote server</source>
        <translation>Nelze rozlišit vzdálený server</translation>
    </message>
    <message>
        <source>Failed to connect to server</source>
        <translation>Selhalo připojení k serveru</translation>
    </message>
    <message>
        <source>SSL error</source>
        <translation>Chyba SSL</translation>
    </message>
    <message>
        <source>Error in network transmission</source>
        <translation>Chyba v síťovém přenosu</translation>
    </message>
    <message>
        <source>Timeout in network transmission</source>
        <translation>Vypršel limit síťového přenosu</translation>
    </message>
    <message>
        <source>Failed to handle http redirection</source>
        <translation>Nepovedlo se zpracovat http přesměrování</translation>
    </message>
    <message>
        <source>Server internal error</source>
        <translation>Vnitřní chyba serveru</translation>
    </message>
    <message>
        <source>Local data is corrupt</source>
        <translation>Místní data jsou poškozené</translation>
    </message>
    <message>
        <source>Failed to write local data</source>
        <translation>Nepovedlo se zapsat místní data</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Neznámá chyba</translation>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation>Byl dosažen datový limit na serveru</translation>
    </message>
    <message>
        <source>SSL Error</source>
        <translation>Chyba SSL</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Chyba sítě: %1</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation>Chyba serveru</translation>
    </message>
    <message>
        <source>Created library &quot;%1&quot;</source>
        <translation>Vytvořena knihovna &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>Smazána knihovna &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Added</source>
        <translation>Přidáno</translation>
    </message>
    <message>
        <source>Deleted</source>
        <translation>Smazáno</translation>
    </message>
    <message>
        <source>Removed</source>
        <translation>Odebráno</translation>
    </message>
    <message>
        <source>Modified</source>
        <translation>Upraveno</translation>
    </message>
    <message>
        <source>Renamed</source>
        <translation>Přejmenováno</translation>
    </message>
    <message>
        <source>Added or modified</source>
        <translation>Přidáno nebo upraveno</translation>
    </message>
    <message>
        <source>Moved</source>
        <translation>Přemístěno</translation>
    </message>
    <message>
        <source>Added directory</source>
        <translation>Přidán adresář</translation>
    </message>
    <message>
        <source>Removed directory</source>
        <translation>Odebraný adresář</translation>
    </message>
    <message>
        <source>Renamed directory</source>
        <translation>Přejmenovaný adresář</translation>
    </message>
    <message>
        <source>Moved directory</source>
        <translation>Přesunutý adresář</translation>
    </message>
    <message>
        <source>files</source>
        <translation>soubory</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>adresáře</translation>
    </message>
    <message>
        <source>and %1 more</source>
        <translation>a %1 dalších</translation>
    </message>
    <message>
        <source>Reverted library to status at</source>
        <translation>Stav knihovny byl navrácen k </translation>
    </message>
    <message>
        <source>Reverted file &quot;%1&quot; to status at %2.</source>
        <translation>Stav souboru &quot;%1&quot; byl navrácen ke stavu k &quot;%2&quot;.</translation>
    </message>
    <message>
        <source>Recovered deleted directory</source>
        <translation>Smazaný adresář byl obnoven</translation>
    </message>
    <message>
        <source>Changed library name or description</source>
        <translation>Název nebo popis knihovny byl změněn</translation>
    </message>
    <message>
        <source>Auto merge by %1 system</source>
        <translation>Automaticky spojeno systémem %1</translation>
    </message>
    <message>
        <source>Just now</source>
        <translation>Právě teď</translation>
    </message>
    <message>
        <source>1 day ago</source>
        <translation>Včera</translation>
    </message>
    <message>
        <source>%1 days ago</source>
        <translation>před %1 dny</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>před 1 hodinou</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>před %1 hodinami</translation>
    </message>
    <message>
        <source>1 minute ago</source>
        <translation>před minutou</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>před %1 minutami</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Adresář</translation>
    </message>
    <message>
        <source>Readonly Folder</source>
        <translation>Složka pouze ke čtení</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>Dokument</translation>
    </message>
    <message>
        <source>PDF Document</source>
        <translation>PDF Dokument</translation>
    </message>
    <message>
        <source>Image File</source>
        <translation>Obrázek</translation>
    </message>
    <message>
        <source>Text Document</source>
        <translation>Textový dokument</translation>
    </message>
    <message>
        <source>Audio File</source>
        <translation>Zvukový soubor</translation>
    </message>
    <message>
        <source>Video File</source>
        <translation>Video soubor</translation>
    </message>
    <message>
        <source>Word Document</source>
        <translation>MS Word dokument</translation>
    </message>
    <message>
        <source>PowerPoint Document</source>
        <translation>MS PowerPoint dokument</translation>
    </message>
    <message>
        <source>Excel Document</source>
        <translation>MS Excel dokument</translation>
    </message>
    <message>
        <source>%1 Client is already running</source>
        <translation>%1 klient již běží</translation>
    </message>
    <message>
        <source>Choose the disk letter for %1</source>
        <translation>Vyberte písmeno disku pro %1</translation>
    </message>
    <message>
        <source>Update to file %1 denied by folder permission setting</source>
        <translation>Aktualizace souboru %1 je zakázaná kvůli oprávnění na složce</translation>
    </message>
    <message>
        <source>Path %1 ends with space or period character</source>
        <translation>Cesta %1 končí mezerou nebo znakem tečky</translation>
    </message>
    <message>
        <source>Path %1 contains invalid characters like &apos;|&apos; or &apos;:&apos;</source>
        <translation>Cesta %1 obsahuje nepovolený znak jako &apos;|&apos; nebo &apos;:&apos;</translation>
    </message>
    <message>
        <source>Created or updated a file %1 in a non-writable library or folder</source>
        <translation>Vytvořen nebo zaktualizován soubor %1 v nezapisovatelné knihovně nebo složce</translation>
    </message>
    <message>
        <source>Concurrent updates to file %1. File is saved as conflict file</source>
        <translation>Souběžné aktualizace souboru %1. Soubor byl uložen jako konfliktní soubor</translation>
    </message>
    <message>
        <source>%1 is not added to a library and will not be uploaded</source>
        <translation>%1 není přidáno do knihovny nebude nahráno</translation>
    </message>
    <message>
        <source>You can only move files/folders within a library or from one library to another library</source>
        <translation>Soubory/složky je možné přesouvat pouze v rámci knihovny nebo z jedné knihovny do jiné</translation>
    </message>
    <message>
        <source>Syncing is denied by cloud-only permission settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not have write permission to the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Waiting for confirmation to delete files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The path %1 contains symbols that are not supported by the Windows system.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to upload file blocks. Please check network or firewall.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to download file. Please check disk space or folder permissions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library cannot be synced since it has too many files.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Files cannot be uploaded to this library due to file number limit settings.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path has character case conflict with existing file or folder. Will not be downloaded</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to change library name since some files are opened in it</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RemoteWipeService</name>
    <message>
        <source>Authorization expired, please re-login</source>
        <translation>Přihlášení vypršelo, přihlašte se prosím</translation>
    </message>
    <message>
        <source>Authorization expired, please re-login. You can find files that are not uploaded yet at ~/Library/CloudStorage</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeaDriveRootDialog</name>
    <message>
        <source>Choose SeaDrive Cache Folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your files will appear in a local cache folder. Please choose the folder:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>choose...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose %1 Cache Folder </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose %1 Cache Folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose %1 cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create %1 folder failed!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeadriveGui</name>
    <message>
        <source>Failed to initialize log: %1</source>
        <translation>Log se nepodařilo spustit: %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>failed to save client id</source>
        <translation>klientské id se nepodařilo uložit</translation>
    </message>
    <message>
        <source>failed to access %1</source>
        <translation>přístup k %1 se nezdařil</translation>
    </message>
    <message>
        <source>incorrect client id</source>
        <translation>nesprávné klientské id</translation>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation>problém při čtení %1</translation>
    </message>
    <message>
        <source>Auto logon failed, fall back to manual login</source>
        <translation>Automatické přihlášení selhalo, vracím se k ručnímu přihlášení</translation>
    </message>
    <message>
        <source>Faild to choose a cache directory</source>
        <translation>Nepodařilo se vybrat složku cache</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create %1 folder</source>
        <translation>Nepodařilo se inicializovat: nepodařilo se vytvořit složku %1</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create %1 logs folder</source>
        <translation>Nepodařilo se inicializovat: nepodařilo se vytvořit složku pro záznamy událostí v %1</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create %1 data folder</source>
        <translation>Nepodařilo se inicializovat: nepodařilo se vytvořit složku pro data %1</translation>
    </message>
    <message>
        <source>Failed to create seadrive cache directory</source>
        <translation>Nepodařilo se vytvořit složku s mezipamětí pro seadrive</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Faild to migrate old data</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SeaDrive %1 with multiple accounts cannot work with macOS version lower than 14.4. Please upgrade your macOS or downgrade SeaDrive to 3.0.9</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To start %1 extension for account %2, you need to click the %3 entry in Finder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileExtensionHandler</name>
    <message>
        <source>Failed to get upload link information for file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No permissions to create a shared link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed get internal link %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to lock file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unlock file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File &quot;%1&quot; is locked by %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get lock information for file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get share link %1
</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileLinkDialog</name>
    <message>
        <source>%1 Internal Link</source>
        <translation>%1 interní odkaz</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Zkopírovat do schránky</translation>
    </message>
    <message>
        <source>%1 Internal Link:</source>
        <translation>%1 Vnitřní odkaz:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>SeafileRpcClient</name>
    <message>
        <source>internal error: failed to connect to %1 daemon</source>
        <translation>vnitřní chyba: nepodařilo se připojit k procesu služby %1</translation>
    </message>
</context>
<context>
    <name>SeafileTrayIcon</name>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Show file sync errors</source>
        <translation>Zobrazit chyby synchronizace</translation>
    </message>
    <message>
        <source>Open &amp;logs folder</source>
        <translation>Otevřít adresář log souborů</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O aplikaci</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>Zobrazit informace O aplikaci</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>&amp;Online nápověda</translation>
    </message>
    <message>
        <source>Accounts</source>
        <translation>Účty</translation>
    </message>
    <message>
        <source>not logged in</source>
        <translation>nepřihlášen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Přidat účet</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <source>&lt;h2&gt;Seafile Drive Client %2&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;Seafile Drive Klient %2&lt;/h2&gt;</translation>
    </message>
    <message>
        <source>Up %1, Down %2</source>
        <translation>Upload %1, Download %2</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <source>Transfer progress</source>
        <translation>Přenos</translation>
    </message>
    <message>
        <source>open %1 log folder</source>
        <translation>otevřít adresář s log soubory %1</translation>
    </message>
    <message>
        <source>open %1 online help</source>
        <translation>otevřít %1 online nápovědu</translation>
    </message>
    <message>
        <source>Show encrypted libraries</source>
        <translation>Zobrazit šifrované knihovny</translation>
    </message>
    <message>
        <source>Starting ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Resync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>There are changes being uploaded under the account, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to remove account from &quot;%1&quot;? After removing account, you can still find downloaded files at ~/Library/CloudStorage.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to connect to background process, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SeaDrive %1 with multiple accounts cannot work with macOS version lower than 14.4. Please upgrade your macOS or downgrade SeaDrive to 3.0.9</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to remove account from &quot;%1&quot;? Downloaded and uploading files will not be removed.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to resync account from &quot;%1&quot;? Downloaded and uploading files will not be removed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to resync account from &quot;%1&quot;? After resyncing account, you can still find downloaded files at ~/Library/CloudStorage.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All file types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom file type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to search&lt;br/&gt;Please %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No result found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchItemsTableModel</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kind</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchItemsTableView</name>
    <message>
        <source>&amp;Open the file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Show in folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File not found, maybe not synchorized yet</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Auto start %1 after login</source>
        <translation>Automaticky spustit %1 po přihlášení</translation>
    </message>
    <message>
        <source>Cache directory:</source>
        <translation>Cache adresář:</translation>
    </message>
    <message>
        <source>Enable search</source>
        <translation>Povolit vyhledávání</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádný</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Proxy</translation>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation>Socks5 Proxy</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Systémová proxy</translation>
    </message>
    <message>
        <source>enabled search</source>
        <translation>povolené vyhledávání</translation>
    </message>
    <message>
        <source>disabled search</source>
        <translation>zakázané vyhledávání</translation>
    </message>
    <message>
        <source>You have %1. Restart to apply it?</source>
        <translation>Máš %1. Restartovat pro aplikování ?</translation>
    </message>
    <message>
        <source>Please choose the cache folder</source>
        <translation>Vyber prosím složku mezipaměti</translation>
    </message>
    <message>
        <source>The proxy host address can&apos;t be empty</source>
        <translation>Proxy adresa hostitele nesmí být prázdná</translation>
    </message>
    <message>
        <source>The proxy port is incorrect</source>
        <translation>Port Proxy je nesprávný</translation>
    </message>
    <message>
        <source>Proxy username can&apos;t be empty</source>
        <translation>Uživatelské jméno proxy nesmí být prázdné</translation>
    </message>
    <message>
        <source>Proxy password can&apos;t be empty</source>
        <translation>Uživatelské heslo proxy nesmí být prázdné</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Notify when libraries are synchronized</source>
        <translation>Informovat, že knihovny byly synchromizovány</translation>
    </message>
    <message>
        <source>Enable sync temporary files of MSOffice/Libreoffice</source>
        <translation>Povolit synchronizaci pro dočasné soubory MSOffice/Libreoffice</translation>
    </message>
    <message>
        <source>Download speed limit (KB/s):</source>
        <translation>Download limit (KB/s):</translation>
    </message>
    <message>
        <source>Upload speed limit (KB/s):</source>
        <translation>Upload limit (KB/s):</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Základní</translation>
    </message>
    <message>
        <source>Enable Explorer Extension</source>
        <translation>Povolit rozšíření Průzkumníku Windows</translation>
    </message>
    <message>
        <source>Do not verify server certificate in HTTPS syncing</source>
        <translation>Neověřovat certifikát při HTTPS synchronizaci</translation>
    </message>
    <message>
        <source>Cache clean interval (in minutes):</source>
        <translation>Interval vyčištění cache (v minutách):</translation>
    </message>
    <message>
        <source>Cache size limit (in GB):</source>
        <translation>Limit velikosti mezipaměti (v GB):</translation>
    </message>
    <message>
        <source>select...</source>
        <translation>vybrat...</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Rozšířené</translation>
    </message>
    <message>
        <source>Language (need restart)</source>
        <translation>Jazyk (vyžaduje restart)</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Jazyk</translation>
    </message>
    <message>
        <source>Proxy Type:</source>
        <translation>Typ proxy:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Proxy server requires a password</source>
        <translation>Proxy server vyžaduje heslo</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Síť</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Enable search in finder</source>
        <translation>Povolit vyhledávání ve vyhledávači</translation>
    </message>
    <message>
        <source>You have changed language, Restart to apply it?</source>
        <translation>Změnil jsi jazyk, restartovat pro aplikování ?</translation>
    </message>
    <message>
        <source>You have changed cache directory. Restart to apply it?</source>
        <translation>Změnil jsi složku cache. Restartovat pro aplikování ?</translation>
    </message>
    <message>
        <source>You have changed %1 cache folder. Restart to apply it?</source>
        <translation>Změnili jste složku pro mezipaměť %1. Restartovat aplikaci pro uplatnění?</translation>
    </message>
    <message>
        <source>0</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide Windows incompatibility paths Message</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Confirm before deleting files more than</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedLinkDialog</name>
    <message>
        <source>Share Link</source>
        <translation>Sdílet odkaz</translation>
    </message>
    <message>
        <source>Share link:</source>
        <translation>Sdílet odkaz:</translation>
    </message>
    <message>
        <source>Direct Download</source>
        <translation>Přímé stažení</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Zkopírovat do schránky</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>Zobrazit heslo</translation>
    </message>
    <message>
        <source>Expire days</source>
        <translation>Za kolik dnů skončit platnost</translation>
    </message>
    <message>
        <source>Generate link</source>
        <translation>Vytvořit odkaz</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to generate share link: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShibLoginDialog</name>
    <message>
        <source>Single Sign On</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SyncCommand</name>
    <message>
        <source>No permissions to create a shared link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to get share link %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed get internal link %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get upload link for file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SyncErrorsDialog</name>
    <message>
        <source>File Sync Errors</source>
        <translation>Chyby synchronizace</translation>
    </message>
    <message>
        <source>No sync errors.</source>
        <translation>Žádné chyby synchronizace</translation>
    </message>
</context>
<context>
    <name>SyncErrorsTableModel</name>
    <message>
        <source>Double click to open the library</source>
        <translation>Dvakrát klikni pro otevření knihovny</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Knihovna</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Cesta</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
</context>
<context>
    <name>TransferItemsTableModel</name>
    <message>
        <source>finished</source>
        <translation>dokončeno</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Postup</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <source>Server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TransferProgressDialog</name>
    <message>
        <source>Transfer Progress</source>
        <translation>Přenos</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Nahrát</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Stáhnout</translation>
    </message>
</context>
<context>
    <name>UninstallHelperDialog</name>
    <message>
        <source>Uninstall %1</source>
        <translation>Odinstalovat %1</translation>
    </message>
    <message>
        <source>Do you want to remove the %1 account information?</source>
        <translation>Chcete odebrat informace o %1 účtu?</translation>
    </message>
    <message>
        <source>Removing account information...</source>
        <translation>Odebírání informací o účtu…</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>text</source>
        <translation>text</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ne</translation>
    </message>
</context>
<context>
    <name>UploadLinkDialog</name>
    <message>
        <source>Upload Link</source>
        <translation>Odkaz na nahrání</translation>
    </message>
    <message>
        <source>Upload link:</source>
        <translation>Odkaz na nahrání:</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Zkopírovat do schránky</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>